@@ -4,7 +4,7 @@
     begin                : Mon Jan 20 2003
     copyright            : (C) 2003-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/02/15 08:18:35 $ by $Author: hftom $
+    last modified        : $Date: 2005/08/06 23:28:07 $ by $Author: hftom $
 
     some code from :
 		dvbstream (GPL), Copyright (C) Dave Chapman 2001,2002
@@ -47,13 +47,9 @@
 #include "dvbevents.h"
 #include "gdvb.h"
 
-#define slof (11700*1000UL)
-#define lof1 (9750*1000UL)
-#define lof2 (10600*1000UL)
 
 
-
-DvbStream::DvbStream( int card, fe_type_t type, QString src )
+DvbStream::DvbStream( int card, fe_type_t type, const QString &src )
 {
 	isRunning = false;
 	timeShifting = false;
@@ -78,7 +74,14 @@ DvbStream::DvbStream( int card, fe_type_t type, QString src )
 
 
 
-void DvbStream::setSources( QString src )
+void DvbStream::setLnb( int pos, LNB b )
+{
+	lnb[pos] = b;
+}
+
+
+
+void DvbStream::setSources( const QString &src )
 {
 	QString s;
 	int pos, i;
@@ -105,19 +108,26 @@ QStringList DvbStream::getSources()
 
 bool DvbStream::canSource( ChannelDesc *chan )
 {
-	if ( chan->tp.type!=dvbType ) return false;
+	if ( chan->tp.type!=dvbType ) {
+		fprintf(stderr,"Wrong dvbType\n");
+		return false;
+	}
 	int i = getSatPos( chan->tp.source );
-	if ( i!=-1 ) return true;
-	else return false;
+	if ( i!=-1 )
+		return true;
+	else
+		return false;
 }
 
 
 
-int DvbStream::getSatPos( QString src )
+int DvbStream::getSatPos( const QString &src )
 {
 	int i;
 
-	for ( i=0; i<(int)source.count(); i++ ) if ( source[i]==src ) return i;
+	for ( i=0; i<(int)source.count(); i++ )
+		if ( source[i]==src )
+			return i;
 	return -1;
 }
 
@@ -142,7 +152,8 @@ bool DvbStream::openFe()
 
 bool DvbStream::closeFe()
 {
-	if ( !fdFrontend ) return true;
+	if ( !fdFrontend )
+		return true;
 	if ( close( fdFrontend )<0 ) {
 		perror("closeFe : ");
 		return false;
@@ -156,8 +167,10 @@ bool DvbStream::closeFe()
 
 void DvbStream::connectStatus( bool con )
 {
-	if ( con ) statusTimer.start( 1000 );
-	else statusTimer.stop();
+	if ( con )
+		statusTimer.start( 1000 );
+	else
+		statusTimer.stop();
 }
 
 
@@ -167,19 +180,47 @@ ChannelDesc DvbStream::getLiveChannel()
 	int i;
 
 	for ( i=0; i<(int)out.count(); i++ ) {
-		if ( out.at(i)->hasLive() ) return out.at(i)->channel;
+		if ( out.at(i)->hasLive() )
+			return out.at(i)->channel;
 	}
 	return ChannelDesc();
 }
 
 
 
+bool DvbStream::hasLive()
+{
+	int i;
+
+	for ( i=0; i<(int)out.count(); i++ ) {
+		if ( out.at(i)->hasLive() )
+			return true;
+	}
+	return false;
+}
+
+
+
 bool DvbStream::hasRec()
 {
 	int i;
 
 	for ( i=0; i<(int)out.count(); i++ ) {
-		if ( out.at(i)->hasRec() ) return true;
+		if ( out.at(i)->hasRec() )
+			return true;
+	}
+	return false;
+}
+
+
+
+bool DvbStream::hasBroadcast()
+{
+	int i;
+
+	for ( i=0; i<(int)out.count(); i++ ) {
+		if ( out.at(i)->hasBroadcast() )
+			return true;
 	}
 	return false;
 }
@@ -192,8 +233,10 @@ bool DvbStream::liveIsRecording()
 
 	for ( i=0; i<(int)out.count(); i++ ) {
 		if ( out.at(i)->hasLive() ) {
-			if ( out.at(i)->hasRec() ) return true;
-			else return false;
+			if ( out.at(i)->hasRec() )
+				return true;
+			else
+				return false;
 		}
 	}
 	return false;
@@ -210,24 +253,29 @@ Transponder DvbStream::getCurrentTransponder()
 
 bool DvbStream::isTuned()
 {
-	if ( fdFrontend ) return true;
-	else return false;
+	if ( fdFrontend )
+		return true;
+	else
+		return false;
 }
 
 
 
 bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 {
-	int tone=-1, status, res;
+	unsigned long lof=0;
+	int status, res, hiband=0;
 	struct dvb_frontend_parameters feparams;
 	struct dvb_frontend_event event;
 	struct dvb_frontend_info fe_info;
 	struct pollfd pf[1];
 	unsigned long freq=chan->tp.freq;
 	unsigned long srate=chan->tp.sr;
+	int lnbPos = getSatPos( chan->tp.source );
 
 	closeFe();
-	if ( !openFe() ) return false;
+	if ( !openFe() )
+		return false;
 
 	if ( (res = ioctl( fdFrontend, FE_GET_INFO, &fe_info ) < 0) ) {
 		perror("FE_GET_INFO: ");
@@ -241,7 +289,8 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 
 	switch( fe_info.type ) {
 		case FE_OFDM : {
-			if (freq < 1000000) freq*=1000UL;
+			if (freq < 1000000)
+				freq*=1000UL;
 			feparams.frequency=freq;
 			feparams.u.ofdm.bandwidth=chan->tp.bandwidth;
 			feparams.u.ofdm.code_rate_HP=chan->tp.coderateH;
@@ -262,28 +311,34 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 			feparams.u.qam.symbol_rate = srate;
 			feparams.u.qam.fec_inner = chan->tp.coderateH;
 			feparams.u.qam.modulation = chan->tp.modulation;
-			fprintf(stderr,"inv:%d sr:%d fecH:%d mod:%d\n", chan->tp.inversion,
+			fprintf(stderr,"inv:%d sr:%lu fecH:%d mod:%d\n", chan->tp.inversion,
 				srate, chan->tp.coderateH, chan->tp.modulation );
 			break;
 		}
 		case FE_QPSK : {
 			fprintf(stderr,"tuning DVB-S to %lu %c %lu\n", freq, chan->tp.pol, srate);
 			if (freq > 2200000) {
-				if (freq < slof) {
-					feparams.frequency=(freq-lof1);
-					tone = SEC_TONE_OFF;
+				if ( lnb[lnbPos].switchFreq ) {
+					if ( freq<(lnb[lnbPos].switchFreq*1000) ) {
+						lof = lnb[lnbPos].loFreq*1000;
+					}
+					else {
+						lof = lnb[lnbPos].hiFreq*1000;
+						hiband = 1;
+					}
 				}
 				else {
-					feparams.frequency=(freq-lof2);
-					tone = SEC_TONE_ON;
+					lof = (lnb[lnbPos].loFreq*1000);
 				}
+				feparams.frequency = ( freq-lof );
 			}
-			else feparams.frequency=freq;
+			else
+				feparams.frequency=freq;
 
 			feparams.u.qpsk.symbol_rate=srate;
 			feparams.u.qpsk.fec_inner=chan->tp.coderateH;
 			fprintf(stderr,"inv:%d fecH:%d\n", chan->tp.inversion, chan->tp.coderateH );
-			if ( setupSwitch( getSatPos( chan->tp.source ), (chan->tp.pol=='h') || (chan->tp.pol=='H'), freq > slof )!=0 ) {
+			if ( setupSwitch( lnbPos, (chan->tp.pol=='h') || (chan->tp.pol=='H'), hiband)!=0 ) {
 				closeFe();
 				return false;
 			}
@@ -291,13 +346,15 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 		}
 	}
 	if ( chan->tp.inversion==INVERSION_AUTO ) {
-		if ( fe_info.caps & FE_CAN_INVERSION_AUTO ) feparams.inversion=chan->tp.inversion;
+		if ( fe_info.caps & FE_CAN_INVERSION_AUTO )
+			feparams.inversion=chan->tp.inversion;
 		else {
 			fprintf(stderr,"Can NOT inversion_auto\n");
 			feparams.inversion=INVERSION_OFF;
 		}
 	}
-	else feparams.inversion=chan->tp.inversion;
+	else
+		feparams.inversion=chan->tp.inversion;
 
 	//usleep(100000);
 
@@ -343,7 +400,7 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 				fprintf(stderr,"Event:  Frequency: %d\n",event.parameters.frequency);
 				break;
 			case FE_QPSK:
-				fprintf(stderr,"Event:  Frequency: %d\n",(unsigned int)((event.parameters.frequency)+(tone==SEC_TONE_OFF ? lof1 : lof2)));
+				fprintf(stderr,"Event:  Frequency: %d\n",(unsigned int)((event.parameters.frequency)+lof));
 				fprintf(stderr,"        SymbolRate: %d\n",event.parameters.u.qpsk.symbol_rate);
 				fprintf(stderr,"        FEC_inner:  %d\n",event.parameters.u.qpsk.fec_inner);
 				fprintf(stderr,"\n");
@@ -361,7 +418,8 @@ bool DvbStream::tuneDvb( ChannelDesc *chan, bool dvr )
 		return false;
 	}
 
-	if ( !dvr ) return true;
+	if ( !dvr )
+		return true;
 
 	if ( ( fdDvr = open( dvrName, O_RDONLY|O_NONBLOCK)) < 0 ) {
 		perror("DVR DEVICE: ");
@@ -402,7 +460,8 @@ int DvbStream::setupSwitch( int switchPos, int voltage18, int hiband )
 	int i = 4 * switchPos + 2 * hiband + (voltage18 ? 1 : 0);
 
 	fprintf( stderr, "DiSEqC: switch pos %i, %sV, %sband (index %d)\n", switchPos, voltage18 ? "18" : "13", hiband ? "hi" : "lo", i );
-	if ( i < 0 || i >= (int)(sizeof(switch_cmds)/sizeof(struct diseqc_cmd)) ) return -EINVAL;
+	if ( i < 0 || i >= (int)(sizeof(switch_cmds)/sizeof(struct diseqc_cmd)) )
+		return -EINVAL;
 	cmd[0] = &switch_cmds[i];
 	return diseqc( i % 2 ? SEC_VOLTAGE_18 : SEC_VOLTAGE_13, cmd,
 		(i/2) % 2 ? SEC_TONE_ON : SEC_TONE_OFF, (i/4) % 2 ? SEC_MINI_B : SEC_MINI_A );
@@ -455,9 +514,11 @@ bool DvbStream::setPids( DVBout *o, int napid )
 	dmx_pes_type_t pestype = DMX_PES_OTHER;
 	QValueList<int> pidList;
 
-	if ( o->channel.vpid!=0 ) pidList.append( o->channel.vpid );
+	if ( o->channel.vpid )
+		pidList.append( o->channel.vpid );
 	pidList.append( o->channel.apid[napid].pid );
-	if ( o->channel.subpid.pid!=0 ) pidList.append( o->channel.subpid.pid );
+	if ( o->channel.subpid[0].pid )
+		pidList.append( o->channel.subpid[0].pid );
 
 	//if ( (ndmx+pidList.count())>MAX_CHANNELS ) return false;
 
@@ -493,7 +554,8 @@ void DvbStream::removePids( DVBout *o )
 {
 	int i;
 
-	for ( i=0; i<(int)o->dmx.count(); i++ ) close( o->dmx[i] );
+	for ( i=0; i<(int)o->dmx.count(); i++ )
+		close( o->dmx[i] );
 	ndmx -=o->dmx.count();
 }
 
@@ -526,7 +588,8 @@ bool DvbStream::checkStatus()
 	memset( &festatus, 0, sizeof(festatus) );
 	ioctl(fdFrontend,FE_READ_STATUS,&festatus);
 
-	if (festatus & FE_HAS_LOCK) emit lockStatus( true );
+	if (festatus & FE_HAS_LOCK)
+		emit lockStatus( true );
 	else {
 		emit lockStatus( false );
 		ret = false;
@@ -539,8 +602,9 @@ bool DvbStream::checkStatus()
 
 bool DvbStream::hasVideo()
 {
-	if ( getLiveChannel().vpid ) return true;
-	else return false;
+	if ( getLiveChannel().vpid )
+		return true;
+	return false;
 }
 
 
@@ -552,7 +616,7 @@ void DvbStream::run()
 	int WSIZE=188*8;
 	DVBout *o=0;
 
-	dvbEvents->go( true );
+	dvbEvents->go( currentTransponder.source, true );
 
 	while ( isRunning ) {
 		poll( &pfd, 1, 500 );
@@ -562,15 +626,21 @@ void DvbStream::run()
 			thWrite+=n;
 			if ( waitPause>0 ) {
 				o = 0;
-				for ( i=0; i<(int)out.count(); i++ ) if ( out.at(i)->hasLive() ) o = out.at(i);
+				for ( i=0; i<(int)out.count(); i++ )
+					if ( out.at(i)->hasLive() )
+						o = out.at(i);
 				if ( o ) {
-					if ( o->doPause( timeShiftFileName ) ) waitPause = 0;
-					else waitPause = -1;
+					if ( o->doPause( timeShiftFileName ) )
+						waitPause = 0;
+					else
+						waitPause = -1;
 				}
-				else waitPause = -1;
+				else
+					waitPause = -1;
 			}
 			if ( thWrite==WSIZE ) {
-				for ( i=0; i<(int)out.count(); i++ ) out.at(i)->process( thBuf, WSIZE );
+				for ( i=0; i<(int)out.count(); i++ )
+					out.at(i)->process( thBuf, WSIZE );
 				thWrite = 0;
 			}
 		}
@@ -582,7 +652,7 @@ void DvbStream::run()
 
 
 
-bool DvbStream::doPause( QString name )
+bool DvbStream::doPause( const QString &name )
 {
 	//if ( !hasVideo() ) return false;
 
@@ -590,8 +660,10 @@ bool DvbStream::doPause( QString name )
 		timeShiftFileName = name;
 		waitPause = 1;
 		while ( waitPause>0 ) usleep(100);
-		if ( waitPause<0 ) return false;
-		else receiveShifting( true );
+		if ( waitPause<0 )
+			return false;
+		else
+			receiveShifting( true );
 		return true;
 	}
 	return false;
@@ -614,7 +686,7 @@ void DvbStream::receiveShifting( bool b )
 
 
 
-bool DvbStream::running()
+bool DvbStream::running() const
 {
 	return isRunning;
 }
@@ -630,11 +702,13 @@ void DvbStream::receivePlayDvb()
 
 void DvbStream::recordEnded( DVBout *o, RecTimer* t, bool kill )
 {
-	if ( t ) emit timerEnded( t );
+	if ( t )
+		emit timerEnded( t );
 	if ( kill ) {
 		removePids( o );
 		removeOut( o );
-		if ( out.count()==0 ) stop();
+		if ( out.count()==0 )
+			stop();
 	}
 	recordingState();
 }
@@ -662,12 +736,125 @@ void DvbStream::updateTimer( RecTimer *t, int ms )
 
 	for ( i=0; i<(int)out.count(); i++ ) {
 		if ( out.at(i)->recTimer==t ) {
-			if ( ms ) out.at(i)->changeTimer( ms );
-			else out.at(i)->stopRec();
+			if ( ms )
+				out.at(i)->changeTimer( ms );
+			else
+				out.at(i)->stopRec();
 			return;
 		}
 	}
-	if ( !ms ) emit timerEnded( t ); // not running
+	if ( !ms )
+		emit timerEnded( t ); // not running
+}
+
+
+
+void DvbStream::stopBroadcast()
+{
+	int i;
+	DVBout *o=0;
+	QPtrList<DVBout> p;
+
+	for ( i=0; i<(int)out.count(); i++ ) {
+		o = out.at(i);
+		o->stopBroadcast();
+		if ( !o->hasLive() && !o->hasRec() )
+			p.append( o );
+	}
+	for ( i=0; i<(int)p.count(); i++ ) {
+		removePids( p.at(i) );
+		removeOut( p.at(i) );
+	}
+	if ( out.count()==0 )
+		stop();
+}
+
+
+
+int DvbStream::canStartBroadcast( bool &live, ChannelDesc *chan )
+{
+	int i, ret=0;
+
+	for ( i=0; i<(int)out.count(); i++ ) {
+		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasRec() )
+			return ErrIsRecording;
+		if ( out.at(i)->hasLive() && chan->tp!=out.at(i)->channel.tp )
+			live = true;
+	}
+	return ret;
+}
+
+
+
+bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
+{
+	int i, j;
+	bool stop=false, newout;
+	DVBout *o=0;
+	int no=0;
+	ChannelDesc *chan=list->at(0);
+
+	if ( !isTuned() ) {
+		for ( i=0; i<3; i++ ) {
+			if ( tuneDvb( chan ) ) {
+				i = -1;
+				break;
+			}
+			else usleep(100000);
+		}
+		if ( i<0 )
+			stop = true;
+		else
+			return false;
+	}
+
+	for ( i=0; i<(int)list->count(); i++ ) {
+		newout = false;
+		o = 0;
+		for ( j=0; j<(int)out.count(); j++ ) {
+			if ( out.at(j)->channel.name==list->at(i)->name )
+				o = out.at(j);
+		}
+
+		if ( !o ) {
+			o = new DVBout( *list->at(i), dvbCard );
+			connect( o, SIGNAL(endRecord(DVBout*,RecTimer*,bool)), this, SLOT(recordEnded(DVBout*,RecTimer*,bool)) );
+			connect( o, SIGNAL(playDvb()), this, SLOT(receivePlayDvb()) );
+			connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
+			out.append( o );
+			if ( !setPids( o, 0 ) ) {
+				removePids( o );
+				removeOut( o );
+				o = 0;
+			}
+			else newout = true;
+		}
+
+		if ( o ) {
+			if ( !o->goBroadcast( rtp ) ) {
+				if ( newout ) {
+					removePids( o );
+					removeOut( o );
+				}
+			}
+			else no++;
+		}
+	}
+
+	if ( !no && stop )
+		stopFrontend();
+
+	fprintf(stderr,"NOUT : %d\n", out.count() );
+	fprintf(stderr,"NO : %d\n", no );
+
+	if ( !isRunning ) {
+		isRunning = true;
+		start();
+	}
+
+	if ( !no )
+		return false;
+	return true;
 }
 
 
@@ -677,11 +864,15 @@ int DvbStream::canStartTimer( bool &live, ChannelDesc *chan )
 	int i, ret=0;
 
 	for ( i=0; i<(int)out.count(); i++ ) {
-		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasRec() ) return ErrIsRecording;
-		if ( (out.at(i)->channel.name==chan->name) && out.at(i)->hasRec() ) return ErrIsRecording;
+		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasRec() )
+			return ErrIsRecording;
+		if ( (out.at(i)->channel.name==chan->name) && out.at(i)->hasRec() )
+			return ErrIsRecording;
 		if ( out.at(i)->hasLive() ) {
-			if ( chan->tp!=out.at(i)->channel.tp ) live = true;
-			else if ( (out.at(i)->channel.name==chan->name) && (out.at(i)->currentAudioPid()!=0) ) live = true;
+			if ( chan->tp!=out.at(i)->channel.tp )
+				live = true;
+			else if ( (out.at(i)->channel.name==chan->name) && (out.at(i)->currentAudioPid()!=0) )
+				live = true;
 		}
 	}
 	return ret;
@@ -694,11 +885,27 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 	int i;
 	bool stop=false, newout=false;
 	DVBout *o=0;
+	QPtrList<DVBout> p;
 
 	for ( i=0; i<(int)out.count(); i++ ) {
-		if ( out.at(i)->channel.name==chan->name ) o = out.at(i);
+		if ( out.at(i)->channel.name==chan->name )
+			o = out.at(i);
+		else {
+			if ( out.at(i)->hasBroadcast() && out.at(i)->channel.tp!=chan->tp ) {
+				p.append( out.at(i) );
+			}
+		}
 	}
 
+	for ( i=0; i<(int)p.count(); i++ ) {
+		p.at(i)->stopBroadcast();
+		removePids( p.at(i) );
+		removeOut( p.at(i) );
+	}
+
+	if ( p.count() )
+		this->stop();
+
 	if ( !isTuned() ) {
 		for ( i=0; i<3; i++ ) {
 			if ( tuneDvb( chan ) ) {
@@ -707,8 +914,10 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 			}
 			else usleep(100000);
 		}
-		if ( i<0 ) stop = true;
-		else return false;
+		if ( i<0 )
+			stop = true;
+		else
+			return false;
 	}
 
 	if ( !o ) {
@@ -718,7 +927,8 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 		connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
 		out.append( o );
 		if ( !setPids( o, 0 ) ) {
-			if ( stop ) stopFrontend();
+			if ( stop )
+				stopFrontend();
 			removePids( o );
 			removeOut( o );
 			return false;
@@ -726,8 +936,12 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 		newout = true;
 	}
 
-	if ( !o->goRec( t->filetype, path+t->name, t ) ) {
-		if ( stop ) stopFrontend();
+	QString name = path+t->name;
+	if ( t->mode )
+		name = name+"-"+t->begin.date().toString( Qt::ISODate );
+	if ( !o->goRec( t->filetype, name, t ) ) {
+		if ( stop )
+			stopFrontend();
 		if ( newout ) {
 			removePids( o );
 			removeOut( o );
@@ -747,15 +961,19 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 
 
 
-int DvbStream::goLive( ChannelDesc *chan, QString pipeName, int &napid )
+int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName, int &napid )
 {
 	int i;
 	bool stop=false;
 	DVBout *o=0;
 
 	for ( i=0; i<(int)out.count(); i++ ) {
-		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasRec() ) return ErrIsRecording;
-		if ( out.at(i)->channel.name==chan->name ) o = out.at(i);
+		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasRec() )
+			return ErrIsRecording;
+		if ( (chan->tp!=out.at(i)->channel.tp) && out.at(i)->hasBroadcast() )
+			return ErrIsBroadcasting;
+		if ( out.at(i)->channel.name==chan->name )
+			o = out.at(i);
 	}
 
 	if ( !isTuned() ) {
@@ -766,8 +984,10 @@ int DvbStream::goLive( ChannelDesc *chan, QString pipeName, int &napid )
 			}
 			else usleep(100000);
 		}
-		if ( i<0 ) stop = true;
-		else return ErrCantTune;
+		if ( i<0 )
+			stop = true;
+		else
+			return ErrCantTune;
 	}
 
 	if ( !o ) {
@@ -777,7 +997,8 @@ int DvbStream::goLive( ChannelDesc *chan, QString pipeName, int &napid )
 		connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
 		out.append( o );
 		if ( !setPids( o, napid ) ) {
-			if ( stop ) stopFrontend();
+			if ( stop )
+				stopFrontend();
 			removePids( o );
 			removeOut( o );
 			return ErrCantSetPids;
@@ -806,21 +1027,26 @@ void DvbStream::stopLive( ChannelDesc *chan )
 {
 	int i;
 	DVBout *o;
+	QPtrList<DVBout> p;
 
 	fprintf(stderr,"Asked to stop\n");
 	for ( i=0; i<(int)out.count(); i++ ) {
 		o = out.at(i);
 		if ( o->hasLive() ) {
 			o->stopLive();
-			if ( !o->hasRec() ) {
-				removePids( o );
-				removeOut( o );
+			if ( !o->hasRec() && !o->hasBroadcast() ) {
+				p.append( o );
 			}
 			break;
 		}
 	}
+	for ( i=0; i<(int)p.count(); i++ ) {
+		removePids( p.at(i) );
+		removeOut( p.at(i) );
+	}
 	fprintf(stderr,"Live stopped\n");
-	if ( out.count()==0 && chan->tp!=currentTransponder ) stop();
+	if ( out.count()==0 && chan->tp!=currentTransponder )
+		stop();
 }
 
 
@@ -846,7 +1072,8 @@ void DvbStream::stopFrontend()
 		fprintf(stderr,"fdDvr closed\n");
 		fdDvr = 0;
 	}
-	if ( fdFrontend ) closeFe();
+	if ( fdFrontend )
+		closeFe();
 	fprintf(stderr,"Frontend closed\n");
 }
 
@@ -861,13 +1088,16 @@ void DvbStream::setScanning( bool b )
 
 void DvbStream::stopScan()
 {
-	if ( fdFrontend ) closeFe();
+	if ( fdFrontend )
+		closeFe();
 }
 
 
 
 DvbStream::~DvbStream()
 {
+	stop();
 	delete dvbEvents;
-	disconnect( &statusTimer, SIGNAL(timeout()), this, SLOT(checkStatus()) );
 }
+
+#include "dvbstream.moc"
