@@ -4,7 +4,7 @@
     begin                : Mon Mar 22 2004
     copyright            : (C) 2004-2005 by Christophe Thommeret
     email                : hftom@free.fr
-    last modified        : $Date: 2005/02/02 10:08:25 $ by $Author: juergenk $
+    last modified        : $Date: 2005/07/21 19:40:30 $ by $Author: hftom $
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,10 +24,10 @@
 #include <qcombobox.h>
 #include <qgroupbox.h>
 #include <qlistview.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qcursor.h>
 #include <qwhatsthis.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qaccel.h>
 
 #include <klocale.h>
@@ -40,10 +40,12 @@
 
 
 
-ScanDialog::ScanDialog( DvbStream *d, QPtrList<ChannelDesc> *ch, QSize size, QString src )
+ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize size, QString src )
 {
 	QString s;
-	
+	int i, j;
+	QStringList list, tmp;
+
 	KIconLoader *icon = new KIconLoader();
 	tvPix = icon->loadIcon( "kdvbtv", KIcon::Small );
 	tvcPix = icon->loadIcon( "kdvbtvc", KIcon::Small );
@@ -54,13 +56,15 @@ ScanDialog::ScanDialog( DvbStream *d, QPtrList<ChannelDesc> *ch, QSize size, QSt
 	dvbsi = 0;
 	dvb = d;
 	sourcesPath = src;
-	
-	searchComb->insertStringList( dvb->getSources() );
-	
-	dvbType = dvb->dvbType;
+
+	for ( i=0; i<(int)dvb->count(); i++ ) {
+		tmp = dvb->at(i)->getSources();
+		for ( j=0; j<(int)tmp.count(); j++ ) list.append( tmp[j] );
+	}
+	searchComb->insertStringList( list );
 
 	setCaption( i18n("Channels") );
-	
+
 	transponders.setAutoDelete( true );
 
 	QGridLayout *statLayout = new QGridLayout( statusFrame, 1, 1, 11, 6 );
@@ -104,33 +108,28 @@ ScanDialog::ScanDialog( DvbStream *d, QPtrList<ChannelDesc> *ch, QSize size, QSt
 			if ( chan->fta ) it->setPixmap( 0, racPix );
 			else it->setPixmap( 0, raPix );
 		}
-	}		
-
-	bool ok=true;
-
-	if ( dvb ) {
-		dvbsi = new DVBsi( &ok, dvb->dvbCard, dvb );
-		if ( !ok ) {
-			delete dvbsi;
-			dvbsi = 0;
-		}
 	}
 
-	if ( dvbsi ) {
-		dvb->setScanning( true );
-		startBtn->setPaletteForegroundColor( QColor(255,0,0) );
-		connect( &checkTimer, SIGNAL( timeout() ), this, SLOT( checkNewChannel() ) );
-		connect( &progressTimer, SIGNAL( timeout() ), this, SLOT( setProgress() ) );
-		connect( startBtn, SIGNAL(toggled(bool)), this, SLOT(scan(bool)) );
-		connect( dvb, SIGNAL(snrStatus(int)), snr, SLOT(setProgress(int)) );
-		connect( dvb, SIGNAL(signalStatus(int)), signal, SLOT(setProgress(int)) );
-		connect( dvb, SIGNAL(lockStatus(bool)), this, SLOT(setLock(bool)) );
-		connect( dvbsi, SIGNAL(end(bool)), this, SLOT(siEnded(bool)) );
-		connect( addfilteredBtn, SIGNAL(clicked()), this, SLOT(addFiltered()) );
-		connect( addselectedBtn, SIGNAL(clicked()), this, SLOT(addSelected()) );
-	}
+	startBtn->setPaletteForegroundColor( QColor(255,0,0) );
 
+	connect( searchComb, SIGNAL(activated(int)), this, SLOT(setDvb(int)) );
+
+	ds = dvb->at(0);
+	ds->setScanning( true );
+	bool ok=false;
+	dvbsi = new DVBsi( &ok, ds->dvbCard, ds );
+	connect( ds, SIGNAL(snrStatus(int)), snr, SLOT(setProgress(int)) );
+	connect( ds, SIGNAL(signalStatus(int)), signal, SLOT(setProgress(int)) );
+	connect( ds, SIGNAL(lockStatus(bool)), this, SLOT(setLock(bool)) );
+	connect( dvbsi, SIGNAL(end(bool)), this, SLOT(siEnded(bool)) );
+
+	connect( &checkTimer, SIGNAL( timeout() ), this, SLOT( checkNewChannel() ) );
+	connect( &progressTimer, SIGNAL( timeout() ), this, SLOT( setProgress() ) );
+	connect( startBtn, SIGNAL(toggled(bool)), this, SLOT(scan(bool)) );
+	connect( addfilteredBtn, SIGNAL(clicked()), this, SLOT(addFiltered()) );
+	connect( addselectedBtn, SIGNAL(clicked()), this, SLOT(addSelected()) );
 	connect( channelsList, SIGNAL(contextMenuRequested(QListViewItem*,const QPoint&,int)), this, SLOT(pop(QListViewItem*,const QPoint&,int)) );
+	connect( channelsList, SIGNAL(doubleClicked(QListViewItem*,const QPoint &,int)), this, SLOT( slotChannelChanged(QListViewItem*,const QPoint &,int) ) );
 	connect( newBtn, SIGNAL(clicked()), this, SLOT(newChannel()) );
 	connect( delBtn, SIGNAL(clicked()), this, SLOT(deleteAll()) );
 
@@ -139,6 +138,53 @@ ScanDialog::ScanDialog( DvbStream *d, QPtrList<ChannelDesc> *ch, QSize size, QSt
 	ac->connectItem( 100, this, SLOT(deleteChannel()) );
 
 	resize( size );
+        delete icon;
+}
+
+
+
+void ScanDialog::slotChannelChanged( QListViewItem *_channel, const QPoint &, int )
+{
+	if ( !_channel ) return;
+	QPixmap pix;
+	QString s = _channel->text(0);
+	if ( edit( s, pix ) ) {
+		_channel->setText( 0, s );
+		_channel->setPixmap( 0, pix );
+	}
+}
+
+
+
+void ScanDialog::setDvb( int index )
+{
+	int i, pos=0;
+	QStringList list;
+	bool ok=false;
+
+	for ( i=0; i<(int)dvb->count(); i++ ) {
+		list = dvb->at(i)->getSources();
+		pos+= list.count();
+		if ( index<pos ) {
+			if ( checkTimer.isActive() ) checkTimer.stop();
+			if ( progressTimer.isActive() ) progressTimer.stop();
+			disconnect( ds, SIGNAL(snrStatus(int)), snr, SLOT(setProgress(int)) );
+			disconnect( ds, SIGNAL(signalStatus(int)), signal, SLOT(setProgress(int)) );
+			disconnect( ds, SIGNAL(lockStatus(bool)), this, SLOT(setLock(bool)) );
+			disconnect( dvbsi, SIGNAL(end(bool)), this, SLOT(siEnded(bool)) );
+			ds->setScanning( false );
+			dvbsi->stop();
+			delete dvbsi;
+			ds = dvb->at(i);
+			ds->setScanning( true );
+			dvbsi = new DVBsi( &ok, ds->dvbCard, ds );
+			connect( ds, SIGNAL(snrStatus(int)), snr, SLOT(setProgress(int)) );
+			connect( ds, SIGNAL(signalStatus(int)), signal, SLOT(setProgress(int)) );
+			connect( ds, SIGNAL(lockStatus(bool)), this, SLOT(setLock(bool)) );
+			connect( dvbsi, SIGNAL(end(bool)), this, SLOT(siEnded(bool)) );
+			break;
+		}
+	}
 }
 
 
@@ -146,9 +192,9 @@ ScanDialog::ScanDialog( DvbStream *d, QPtrList<ChannelDesc> *ch, QSize size, QSt
 void ScanDialog::pop( QListViewItem *it, const QPoint &pos, int col )
 {
 	QPoint p=pos;
-	
+
 	if ( !it ) return;
-	
+
 	int i=col;
 	QPixmap pix;
 	QString s = it->text(0);
@@ -161,7 +207,7 @@ void ScanDialog::pop( QListViewItem *it, const QPoint &pos, int col )
 	switch ( i ) {
 		case 0 :
 			break;
-		case 1 : 
+		case 1 :
 			if ( edit( s, pix ) ) {
 				it->setText( 0, s );
 				it->setPixmap( 0, pix );
@@ -188,7 +234,7 @@ void ScanDialog::deleteChannel( QString name )
 {
 	int j, i;
 	QListViewItem *it;
-	
+
 	for ( j=0; j<(int)chandesc->count(); j++ ) {
 		if ( chandesc->at(j)->name==name ) {
 			for ( i=0; i<(int)chandesc->count(); i++ ) {
@@ -219,14 +265,15 @@ void ScanDialog::newChannel()
 {
 	ChannelDesc chan;
 	QStringList list;
-	int i;
-	
-	for ( i=0; i<(int)searchComb->count(); i++ ) list.append( searchComb->text(i) );
+	//int i;
+
+	//for ( i=0; i<(int)searchComb->count(); i++ ) list.append( searchComb->text(i) );
+	list.append( searchComb->currentText() );
 
 	chandesc->append( new ChannelDesc( chan ) );
-	chan.tp.type = dvbType;
+	chan.tp.type = ds->dvbType;
 	chan.num = chandesc->count();
-	
+
 	ChannelEditor dlg( list, false, &chan, chandesc, this );
 
 	int ret = dlg.exec();
@@ -269,9 +316,9 @@ bool ScanDialog::edit( QString &name, QPixmap &pix )
 	ChannelDesc *chan=0;
 	QStringList list;
 	int i;
-	
+
 	for ( i=0; i<(int)searchComb->count(); i++ ) list.append( searchComb->text(i) );
-	
+
 	for ( j=0; j<(int)chandesc->count(); j++ ) {
 		chan = chandesc->at(j);
 		if ( chan->name==name ) {
@@ -305,7 +352,7 @@ void ScanDialog::parseTp( QString s, fe_type_t type, QString src )
 	Transponder *trans;
 	QString t;
 	int pos;
-	
+
 	s = s.stripWhiteSpace();
 	trans = new Transponder();
 	pos = s.find(" ");
@@ -366,6 +413,12 @@ void ScanDialog::parseTp( QString s, fe_type_t type, QString src )
 		else if ( s.left(pos)=="8/9" ) trans->coderateL = FEC_8_9;
 		else if ( s.left(pos)=="NONE" ) trans->coderateL = FEC_NONE;
 		else trans->coderateL = FEC_AUTO;
+		
+		if ( trans->coderateH==FEC_NONE )
+			trans->coderateH = FEC_AUTO;
+		if ( trans->coderateL==FEC_NONE )
+			trans->coderateL = FEC_AUTO;
+			
 		s = s.right( s.length()-pos-1 );
 		s = s.stripWhiteSpace();
 		pos = s.find(" ");
@@ -413,9 +466,9 @@ void ScanDialog::parseTp( QString s, fe_type_t type, QString src )
 bool ScanDialog::getTransData()
 {
 	QString s=sourcesPath;
-	
+
 	transponders.clear();
-	switch (dvbType) {
+	switch ( ds->dvbType ) {
 		case FE_QPSK : s += "dvb-s/"; break;
 		case FE_QAM : s += "dvb-c/"; break;
 		case FE_OFDM : s += "dvb-t/";
@@ -428,7 +481,7 @@ bool ScanDialog::getTransData()
 			s = tt.readLine();
 			if ( s.startsWith("#") ) continue;
 			if ( s.length()==0 ) continue;
-			parseTp( s, dvbType, searchComb->currentText() );
+			parseTp( s, ds->dvbType, searchComb->currentText() );
 		}
 		f.close();
 		return true;
@@ -443,6 +496,7 @@ void ScanDialog::addSelected()
 	ChannelDesc *chan;
 	QListViewItem *it;
 	int i, j, r;
+	QStringList list;
 	int n = foundList->currentItem();
 
 	if ( n<0 ) return;
@@ -460,8 +514,8 @@ void ScanDialog::addSelected()
 		if ( !chan ) continue;
 		for ( n=0; n<(int)chandesc->count(); n++ ) {
 			if ( chan->name==chandesc->at(n)->name ) {
-				KMessageBox::sorry( this, i18n("This channel already exists : ")+chan->name );
 				r++;
+				list.append( chan->name );
 				break;
 			}
 		}
@@ -481,6 +535,7 @@ void ScanDialog::addSelected()
 		dvbsi->channels.remove(j);
 		i--;
 	}
+	if ( list.count() ) KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
 }
 
 
@@ -503,18 +558,19 @@ void ScanDialog::addFiltered()
 	QListViewItem *it;
 	int m = dvbsi->channels.count();
 	int t=0;
+	QStringList list;
 
 	working( true );
 	startBtn->setEnabled( false );
 	progress->setProgress(0);
 	qApp->processEvents();
-	
+
 	for ( i=0; i<(int)dvbsi->channels.count(); i++ ) {
 		t++;
 		progress->setProgress( t*100/m );
 		chan = dvbsi->channels.at(i);
 		if ( !chan->completed ) continue;
-		if ( chan->name =="" ) continue;
+		if ( chan->name.isEmpty() ) continue;
 		if ( chan->type<1 ) continue;
 		if ( chan->type>2 ) continue;
 		if ( chan->type==1 && chan->vpid==0 ) continue;
@@ -529,6 +585,7 @@ void ScanDialog::addFiltered()
 		it = channelsList->firstChild();
 		while ( it!=0 ) {
 			if ( chan->name==it->text(0) ) {
+				list.append( chan->name );
 				j++;
 				break;
 			}
@@ -560,11 +617,12 @@ void ScanDialog::addFiltered()
 			}
 		}
 	}
+	if ( list.count() ) KMessageBox::informationList( this, i18n("These channels already exist and were not added :"), list );
 	progress->setProgress(0);
 	startBtn->setEnabled( true );
 	working( false );
 }
-		
+
 
 
 void ScanDialog::siEnded( bool b )
@@ -591,7 +649,7 @@ void ScanDialog::scan( bool b )
 		foundList->clear();
 		nChannels = 0;
 		ntv = nradio = 0;
-		if ( dvb->isTuned() ) dvbsi->go( transponders, 2 );
+		if ( ds->isTuned() ) dvbsi->go( transponders, 2 );
 		else {
 			if ( !getTransData() ) return;
 			dvbsi->go( transponders );
@@ -601,6 +659,7 @@ void ScanDialog::scan( bool b )
 		working( true );
 		startBtn->setText( i18n("STOP scan") );
 		startBtn->setPaletteForegroundColor( QColor(0,255,0) );
+		searchComb->setEnabled( false );
 	}
 	else {
 		//setCursor(QCursor(Qt::WaitCursor));
@@ -620,6 +679,7 @@ void ScanDialog::scan( bool b )
 		startBtn->setText( i18n("START scan") );
 		startBtn->setEnabled( true );
 		startBtn->setPaletteForegroundColor( QColor(255,0,0) );
+		searchComb->setEnabled( true );
 	}
 }
 
@@ -645,12 +705,12 @@ void ScanDialog::checkNewChannel()
 {
 	ChannelDesc *chan;
 	int j;
-	
+
 	for ( j=nChannels; j<(int)dvbsi->channels.count(); j++ ) {
 		chan = dvbsi->channels.at(j);
 		if ( chan->completed==0 ) break;
 		nChannels++;
-		if ( chan->name =="" ) continue;
+		if ( chan->name.isEmpty() ) continue;
 		if ( chan->type<1 ) continue;
 		if ( chan->type>2 ) continue;
 		if ( chan->type==1 && chan->vpid==0 ) continue;
@@ -666,7 +726,7 @@ void ScanDialog::checkNewChannel()
 void ScanDialog::addFound( ChannelDesc *chan, bool scan )
 {
 	int i;
-	
+
 	if ( chan->type==1 ) {
 		if ( scan ) ntv++;
 		if ( chan->fta ) foundList->insertItem( tvcPix, chan->name );
@@ -678,7 +738,7 @@ void ScanDialog::addFound( ChannelDesc *chan, bool scan )
 		else foundList->insertItem( raPix, chan->name );
 	}
 	if ( scan ) progressLab->setText( QString( i18n("Found : %1 TV - %2 radio") ).arg(ntv).arg(nradio) );
-	if ( chan->provider=="" ) return;
+	if ( chan->provider.isEmpty() ) return;
 	for ( i=0; i<providerComb->count(); i++ ) {
 		if ( chan->provider==providerComb->text(i) ) {
 			i = -1;
@@ -694,7 +754,11 @@ ScanDialog::~ScanDialog()
 {
 	if ( checkTimer.isActive() ) checkTimer.stop();
 	if ( progressTimer.isActive() ) progressTimer.stop();
-	if ( dvbsi ) delete dvbsi;
-	dvb->setScanning( false );
+	dvbsi->stop();
+        delete dvbsi;
+
+        ds->setScanning( false );
 	transponders.clear();
 }
+
+#include "scandialog.moc"
