@@ -2,8 +2,8 @@
                            urllistview.cpp
                              -------------------
     begin                : Mon Apr 28 2003
-    revision             : $Revision: 1.18 $
-    last modified        : $Date: 2005/02/02 10:08:20 $ by $Author: juergenk $
+    revision             : $Revision: 1.19 $
+    last modified        : $Date: 2005/05/15 18:02:56 $ by $Author: juergenk $
     copyright            : (C) 2003-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -222,7 +222,7 @@ void UrlListView::slotAddSubtitle()
    QString subtitleURL = KFileDialog::getOpenURL(openURL,
                          i18n("*.smi *.srt *.sub *.txt *.ssa *.asc|Subtitle Files\n*.*|All Files"),
                          0, i18n("Select a subtitle file")).path();
-   if(!(subtitleURL == "") && !(m_itemOfContextMenu->subtitles().contains(subtitleURL)) && QFile::exists(subtitleURL))
+   if(!(subtitleURL.isEmpty()) && !(m_itemOfContextMenu->subtitles().contains(subtitleURL)) && QFile::exists(subtitleURL))
    {
      m_itemOfContextMenu->addSubtitle(subtitleURL);
      emit signalPlayItem(m_itemOfContextMenu);
