@@ -2,8 +2,8 @@
                           wizarddialog.cpp  
                              -------------------
     begin                : Son Feb 8 2004
-    revision             : $Revision: 1.10 $
-    last modified        : $Date: 2005/02/02 10:08:21 $ by $Author: juergenk $
+    revision             : $Revision: 1.11 $
+    last modified        : $Date: 2005/04/04 15:13:03 $ by $Author: juergenk $
     copyright            : (C) 2004-2005 by Jürgen Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -37,7 +37,9 @@
 
 #include "wizarddialog.h"
 #include "wizarddialog.moc"
-
+#ifdef HAVE_LINUX_DVB_FRONTEND_H
+#include "dvbconfig.h"
+#endif
 
 WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( parent, name )
 {
@@ -57,23 +59,26 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
   
   QString infoString;
   QTextStream info(&infoString, IO_WriteOnly);
-  
+
+//KAFFEINE-PART
+
   info << "<b>" << i18n("Kaffeine Part") << "...</b><br>";
   KService::Ptr service = KService::serviceByDesktopName("kaffeine_part");
   if ((service) && (service->serviceTypes().contains("KMediaPart")))
     info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>";
    else 
     info << "<font color=\"DarkRed\">" << i18n("Part not found. Please check your installation!") << "</font>";
-   
-  info << "<hr><b>" << "KDE" << "...</b><br>";  
+
+//KAFFEINE-PART
+  info << "<br><hr><b>" << "KDE" << "...</b><br>";  
   info << i18n("Found version") << ": " << KDE::versionString() << "<br>";
   if (KDE::version() >= KDE_MAKE_VERSION(3,2,0))
     info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>";
    else
     info << "<font color=\"DarkRed\">" << i18n("Kaffeine requires KDE >= %1.").arg("3.2") << "</font>"; 
   
-       
-  info << "<hr><b>" << "xine-lib" << "...</b><br>";  
+//XINE-LIB
+  info << "<br><hr><b>" << "xine-lib" << "...</b><br>";  
   QString xineVersion = xine_get_version_string();
   info << i18n("Found version") << ": " << xineVersion << "<br>";
   if (xine_check_version(1,0,0))
@@ -82,22 +87,19 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
     xine_get_version(&major, &minor, &sub);
     if (xineVersion.contains("CVS", false))
       info << "<font color=\"DarkBlue\">" << i18n("Developer version.") << "</font>";
-    else if ((major == 1) && (minor == 0) && (sub == 0) && (xineVersion.contains("rc", false)))
+
+    if ((major == 1) && (minor == 0) && (sub == 0) && (xineVersion.contains("rc", false)))
     {
-       int rc = xineVersion.remove(0, xineVersion.findRev('c') +1).left(1).toInt();
-       if (rc > 4)
-         info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>";
-	else 
-	 info << "<font color=\"DarkRed\">" << i18n("Kaffeine requires xine-lib >= %1. Download the latest version here:").arg("1.0rc5") 
-	 << " <a href=\"http://www.xinehq.de\">http://www.xinehq.de</a>.</font>"; 
-    }	 
+      info << "<font color=\"DarkRed\">" << i18n("Kaffeine requires xine-lib >= %1. Download the latest version here:").arg("1.0") << " <a href=\"http://www.xinehq.de\">http://www.xinehq.de</a>.</font>";
+    }
     else
       info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>";
   }
   else
-    info << "<font color=\"DarkRed\">" << i18n("Kaffeine requires xine-lib >= %1. Download the latest version here:").arg("1.0rc5") 
+    info << "<font color=\"DarkRed\">" << i18n("Kaffeine requires xine-lib >= %1. Download the latest version here:").arg("1.0")
          << " <a href=\"http://www.xinehq.de\">http://www.xinehq.de</a>.</font>";  
-  
+
+//WIN32-CODECS
   info << "<hr><b>" << i18n("WIN32 Codecs") << "...</b><br>";  
   QDir d("/usr/lib/win32");
   QStringList entries = d.entryList("wmv*");
@@ -106,8 +108,9 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
    else    
     info << "<font color=\"DarkRed\">" << i18n("No WIN32 codecs found in /usr/lib/win32. You're not able to play Windows Media 9 files, newer Real Media files and some less common formats. Download the codecs here:")
     << " <a href=\"http://www1.mplayerhq.hu/homepage/design7/codecs.html\">http://www.mplayerhq.hu</a>.</font>"; 
-  
-  info << "<hr><b>" << "libdvdcss" << "...</b><br>";      
+
+//LIBDVDCSS
+  info << "<br><hr><b>" << "libdvdcss" << "...</b><br>";      
   bool dvdcss = false;
   d = QDir("/usr/lib"); 
   entries = d.entryList("libdvdcss.so*"); 
@@ -132,8 +135,9 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
     << " <a href=\"http://developers.videolan.org/libdvdcss/\">http://developers.videolan.org/libdvdcss</a>.</font>";
    else   
     info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>"; 
-   
-  info << "<hr><b>" << i18n("DVD Drive") << "...</b><br>";   
+
+//DVD-DRIVE
+  info << "<br><hr><b>" << i18n("DVD Drive") << "...</b><br>";
   KProcess process;
   process << "/sbin/hdparm" << "-d" << "/dev/dvd";
   connect(&process, SIGNAL(receivedStdout(KProcess*,char*,int)), this, SLOT(slotReceivedStdout(KProcess*, char*, int)));
@@ -146,9 +150,22 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
       else
         info << "<font color=\"DarkBlue\">" << i18n("Can't check DMA mode. Permission denied or no such device:") 
 	<< " \"/dev/dvd\".</font>";
-     
-    
-  info << "<hr><b>" << i18n("Distribution") << "...</b><br>"; 
+
+//DVB-DEVICES
+#ifdef HAVE_LINUX_DVB_FRONTEND_H
+    info << "<br><hr><b>" << i18n("DVB-Device") << "...</b><br>";
+    if (DVBconfig::haveDvbDevice())
+    {
+       info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>";
+    }
+    else
+    {
+       info << "<font color=\"DarkBlue\">" << i18n("No DVB-Devices found. The DVB related functions will be hidden.") << "</font>";
+    }
+#endif
+
+//DISTRIBUTION
+  info << "<br><hr><b>" << i18n("Distribution") << "...</b><br>"; 
   if (QFile::exists("/etc/SuSE-release"))
   {
     QFile file("/etc/SuSE-release");
@@ -163,7 +180,7 @@ WizardDialog::WizardDialog( QWidget *parent, const char *name ) : KWizard( paren
    info << "<font color=\"DarkGreen\">" << i18n("Ok.") << "</font>"; 
   
     
-  info << "<hr><hr><br><b>" << i18n("RESULT") << ":</b> ";
+  info << "<hr><br><b>" << i18n("RESULT") << ":</b> ";
   
   if (infoString.contains("DarkRed"))
   {
